@@ -1,5 +1,5 @@
 import tensorflow as tf
-
+import pandas as pd
 import sys
 import os
 
@@ -9,9 +9,9 @@ top_path = top_path.split('jhsp')[0]
 top_path = os.path.join(top_path, 'jhsp')
 sys.path.append(top_path)
 
-from Sann.models import sann,ann,sanntuner
+from Sann.models import sann,sanntuner,anntuner
 from Sann import getweights,weights22netweights
-
+import tensorflow_addons as tfa
 
 
 
@@ -19,20 +19,25 @@ class GetSannModel():
     """
     返回SANN模型和网络结构一样的ANN模型
     """
-    def __init__(self,x,y,how):
+    def __init__(self,x,y,how,weights):
 
-        gw = getweights.GetWeights(x, y)
-        self.weights = gw.GetW()
+
+        self.weights = weights
+        self.out_units = y.shape[1]
 
 
         if how == 'mull':
             self.final_activation = 'sigmoid'
-            self.loss = tf.keras.losses.BinaryCrossentropy()
+            self.loss = 'binary_crossentropy'
             self.metrics = 'accuracy'
         if how == 'mulc':
             self.final_activation = 'softmax'
             self.loss = 'categorical_crossentropy'
             self.metrics = 'accuracy'
+        if how =='2c':
+            self.final_activation = 'sigmoid'
+            self.loss = 'binary_crossentropy'
+            self.metrics = 'accuracy'
 
     # 标签还是分类 ，加一个参数
     def GetSann(self,hp):
@@ -42,22 +47,31 @@ class GetSannModel():
 
         return model
 
-    def GetCorAnn(self,x, y, hidden_layers):
+    def GetAnn(self,hp):
         """
         获得与SANN网络结构一致的ANN
         :return:
         """
-        gw = getweights.GetWeights(x, y)
-        w22n = weights22netweights.W22NW()
-        initial_weigh,error = w22n.Weights2HW(gw.GetW(), hidden_layers, False)
 
-        model = ann.Model(initial_weigh, self.final_activation)
+        model = anntuner.Model(self.final_activation,self.out_units,hp)
         model.compile(loss=self.loss, optimizer='adam', metrics=[self.metrics])
 
         return model
 
+    def GetSannmyself(self,hidden_layers,drop_rate):
+
+
+        weights = weights22netweights.W22NW().Weights2HW(self.weights,hidden_layers,save=False)[0]
+
+
+
+
+        model = sann.Model(weights, self.final_activation,drop_rate)
+        model.compile(loss=self.loss, optimizer=tf.keras.optimizers.Adam(0.3), metrics=['accuracy'])
+
+        return model
+
 
 
 
 
-
